==> twpsk_4.1.orig.tar.gz: twpsk-4.1/src/GUI.h <==
//#include <Xm/CutPaste.h>
/*
 * GUI.h Header File
 */

/* twpsk:  A gui application for PSK
 * Copyright (C) 1999-2014 Ted Williams WA0EIR 
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of
 * the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied
 * warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
 * PURPOSE.  See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public
 * License along with this program; if not, write to the Free
 * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139,
 * USA.
 *
 * Version: 4.1 - Feb 2014
 */

/*
 * Include Files
 */
#ifndef GUI_INCLUDED
#define GUI_INCLUDED

#include "../config.h"
#include <stdio.h>
#include <math.h>
#include <unistd.h>
#include <sys/stat.h>
#include <ctype.h>
#include <stdlib.h>
#include <sys/ioctl.h>
#include <fcntl.h>
#include <errno.h>
#include <sys/soundcard.h>
#include <X11/cursorfont.h>
#include <Xm/Xm.h>
#include <Xm/Form.h>
#include <Xm/CascadeB.h>
#include <Xm/PushB.h>
#include <Xm/Separator.h>
#include <Xm/PanedW.h>
#include <Xm/Frame.h>
#include <Xm/Label.h>
#include <Xm/Scale.h>
#include <Xm/DrawingA.h>
#include <Xm/ScrolledW.h>
#include <Xm/Text.h>
#include <Xm/Scale.h>
#include <Xm/RowColumn.h>
#include <Xm/TextF.h>
#include <Xm/ToggleB.h>
#include <Xm/SelectioB.h>
#include <Xm/MessageB.h>
#include <Xm/ArrowB.h>
#include <Xm/DialogS.h>
#include <Xm/MwmUtil.h>
#include <Xm/Protocols.h>
#include <X11/StringDefs.h>

#define MAX_DECODERS 4   /* number of secondary decoders */

#define MAKE_ICON    1
#define CANCEL_BTN   8000
#define SAMPLE_RATE  8000

#define DAT_DIR      "/.twpskDir"
#define DAT_FILE     "/.twpsk.dat"

#define WF_WIDTH     128 * 3
#define WF_HEIGHT    75

#define MAXFREQ      4000.0
#define MAXFREQSTR   "MAXFREQ"

#define RED     0
#define YELLOW  1
#define GREEN   2
#define PTT_ON  TIOCMBIS
#define PTT_OFF TIOCMBIC

/*
 * Application Defined Resources
 */
#define XmNbuttonNames     "buttonNames"
#define XmCButtonNames     "ButtonNames"

#define XmNxmitHighlight   "xmitHighlight"
#define XmCXmitHighlight   "XmitHighlight"

#define XmNrxFreq          "rxFreq"
#define XmCRxFreq          "RxFreq"

#define XmNtxFreq          "txFreq"
#define XmCTxFreq          "TxFreq"

#define XmNafc             "afc"
#define XmCAfc             "Afc"

#define XmNnet             "net"
#define XmCNet             "Net"

#define XmNcall            "call"
#define XmCCall            "Call"

#define XmNzero            "zero"
#define XmCZero            "Zero"

#define XmNserDev          "serDev"
#define XmCSerDev          "SerDev"

#define XmNptt             "ptt"
#define XmCPtt             "Ptt"

#define XmNcallBox         "callBox"
#define XmCCallBox         "CallBox"

#define XmNpostamble       "postamble"
#define XmCPostamble       "Postamble"

#define XmNsampsize        "sampsize"
#define XmCSampsize        "Sampsize"

#define KEY 6146            /* things for shared memory */
#define MAXCALL 12
#define SHMSIZE 2 * MAXCALL

typedef struct 
{
   char inCall[MAXCALL];    /* Note: the names are reversed */
   char outCall[MAXCALL];
}  callspt;

typedef struct 
{
   char    **buttonNames;
   int     xmitHighlight;
   float   rxFreq;
   float   txFreq;
   int     afc;
   int     net;
#if 0
   int     mainVol;
   int     outVol;
   int     inVol;
#endif
   String  call;
   int     zero;
   String  serDev;
   int     ptt;
   int     callBox;
   int     postamble;
   int     sampsize;
} AppRes;

#if 0
typedef struct 
{
   int recsrc;
   int vol;
   int pcm;
   int line;
   int mic;
   int useRec;
} MixVals;
#endif

/*
 * Function Declarations
 */
int  iniProc (char mode);
void controlsBtnCB (Widget w, XtPointer cdata, XtPointer cbs);
void popupDiagCB (Widget w, XtPointer cdata, XtPointer cbs);
void closeVideoDiagCB (Widget w, XtPointer cdata, XtPointer cbs);
void wideBtnCB (Widget w, XtPointer cdata, XtPointer cbs);
void mediunBtnCB (Widget w, XtPointer cdata, XtPointer cbs);
void narrowBtnCB (Widget w, XtPointer cdata, XtPointer cbs);
Boolean workProc(XtPointer cdata);
void appendRXtext (Widget w, char ch, int zero, XmHighlightMode mode);
void appendTXtext (char ch, int zero);
void rxScrollBarCB (Widget w, XtPointer cdata, XtPointer cbs);
void changeDisplayCB (Widget w, XtPointer cdata, XtPointer cbs);
void txTextCB (Widget w, XtPointer cdata, XtPointer cbs);
void txCB (Widget w, XtPointer cdata, XtPointer cbs);
void rxCB (Widget w, XtPointer cdata, XtPointer cbs);
void changeBG (void);
void tuneCB (Widget w, XtPointer cdata, XtPointer cbs);
void arrowCB (Widget w, XtPointer cdata, XtPointer cbs);
void freqTextCB (Widget w, XtPointer cdata, XtPointer cbs);
void afcCB (Widget w, XtPointer cdata, XtPointer cbs);
void netCB (Widget w, XtPointer cdata, XtPointer cbs);
void scopeCB (Widget w, XtPointer cdata, XtPointer cbs);
void wfCB (Widget w, XtPointer cdata, XtPointer cbs);
void wfDirCB (Widget w, XtPointer cdata, XtPointer cbs);
void localCapsCB (Widget w, XtPointer cdata, XtPointer cbs);
void openBtnCB (Widget w, XtPointer cdata, XtPointer cbs);
//void audioCB (Widget w, XtPointer cdata, XtPointer cbs);
void chansCB (Widget w, XtPointer cdata, XtPointer cbs);
void setLevel (int device, int level);
void qpskCB (Widget w, XtPointer cdata, XtPointer cbs);
void lsbCB (Widget w, XtPointer cdata, XtPointer cbs);
void dcdCB (Widget w, XtPointer cdata, XtPointer cbs);
void bwCB (Widget w, XtPointer cdata, XtPointer cbs);
void brightCB (Widget w, XtPointer cdata, XtPointer cbs);
void fftScaleCB (Widget w, XtPointer cdata, XtPointer cbs);
void fileCB (Widget w, XtPointer cdata, XtPointer cbs);
void quitCB (Widget w, XtPointer cdata, XtPointer cbs);
void aboutCB (Widget w, XtPointer cdata, XtPointer cbs);
void helpCB (Widget w, XtPointer cdata, XtPointer cbs);
void errorDiag (Widget w, char *emess, int flag);
void errOkCB (Widget w, XtPointer cdata, XtPointer cbs);
void errCancelCB (Widget w, XtPointer cdata, XtPointer cbs);
void promptDiag (char *word);
Boolean procFileText (XtPointer text); 
void popupHandler (Widget w, XtPointer cdata, XEvent *event, Boolean *cont);
void clrTextCB (Widget w, XtPointer cdata, XtPointer cbs);
char *getFile (char*filename);
void rxFreqFocusCB (Widget w, XtPointer cdata, XtPointer cbs);
int open2Rx (int x);
void seekCB (Widget w, XtPointer cdata, XtPointer cbs);
void haltCB (Widget w, XtPointer cdata, XtPointer cbs);
void bordersCB (Widget w, XtPointer cdata, XtPointer cbs);
void sendOver (Widget w, XEvent *e, String args[], Cardinal *argc);
void sendHisCall (Widget w, XEvent *e, String args[], Cardinal *argc);
void sendMacro (Widget w, XEvent *e, String args[], Cardinal *argc);
char *getHisCall (void);
void procMacroText (char *ch);
void seekTimeOut (XtPointer cdata, XtIntervalId id);
void callbox (Widget shell);
void gotSig (int stat);
void infoText (char *text);
int  getQSOfiles(char *destdir);

void rxTextCB (Widget w, XtPointer cdata, XtPointer cbs);
#endif

==> twpsk_4.2.orig.tar.gz: twpsk-4.2/src/GUI.h <==
/*
 * GUI.h Header File
 */

/* twpsk:  A gui application for PSK
 * Copyright (C) 1999-2014 Ted Williams WA0EIR 
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of
 * the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied
 * warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
 * PURPOSE.  See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public
 * License along with this program; if not, write to the Free
 * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139,
 * USA.
 *
 * Version: 4.1 - Feb 2014
 */

/*
 * Include Files
 */
#ifndef GUI_INCLUDED
#define GUI_INCLUDED

#include "../config.h"
//#include "../../twHEADERS/twSHM.h"
#include <stdio.h>
#include <math.h>
#include <unistd.h>
#include <sys/stat.h>
#include <ctype.h>
#include <stdlib.h>
#include <sys/ioctl.h>
#include <fcntl.h>
#include <errno.h>
#include <sys/soundcard.h>
#include <X11/cursorfont.h>
#include <Xm/Xm.h>
#include <Xm/Form.h>
#include <Xm/CascadeB.h>
#include <Xm/PushB.h>
#include <Xm/Separator.h>
#include <Xm/PanedW.h>
#include <Xm/Frame.h>
#include <Xm/Label.h>
#include <Xm/Scale.h>
#include <Xm/DrawingA.h>
#include <Xm/ScrolledW.h>
#include <Xm/Text.h>
#include <Xm/Scale.h>
#include <Xm/RowColumn.h>
#include <Xm/TextF.h>
#include <Xm/ToggleB.h>
#include <Xm/SelectioB.h>
#include <Xm/MessageB.h>
#include <Xm/ArrowB.h>
#include <Xm/DialogS.h>
#include <Xm/MwmUtil.h>
#include <Xm/Protocols.h>
#include <X11/StringDefs.h>

#define MAX_DECODERS 4   /* number of secondary decoders */

#define MAKE_ICON    1
#define CANCEL_BTN   1
#define ERR_DIAG     1

#define SAMPLE_RATE  8000

#define DAT_DIR      "/.twpskDir"
#define DAT_FILE     "/.twpsk.dat"

#define WF_WIDTH     128 * 3
#define WF_HEIGHT    75

#define MAXFREQ      4000.0
#define MAXFREQSTR   "MAXFREQ"

#define RED     0
#define YELLOW  1
#define GREEN   2
#define PTT_ON  TIOCMBIS
#define PTT_OFF TIOCMBIC

/*
 * Application Defined Resources
 */
#define XmNbuttonNames     "buttonNames"
#define XmCButtonNames     "ButtonNames"

#define XmNxmitHighlight   "xmitHighlight"
#define XmCXmitHighlight   "XmitHighlight"

#define XmNrxFreq          "rxFreq"
#define XmCRxFreq          "RxFreq"

#define XmNtxFreq          "txFreq"
#define XmCTxFreq          "TxFreq"

#define XmNafc             "afc"
#define XmCAfc             "Afc"

#define XmNnet             "net"
#define XmCNet             "Net"

#define XmNcall            "call"
#define XmCCall            "Call"

#define XmNzero            "zero"
#define XmCZero            "Zero"

#define XmNserDev          "serDev"
#define XmCSerDev          "SerDev"

#define XmNptt             "ptt"
#define XmCPtt             "Ptt"

#define XmNcallBox         "callBox"
#define XmCCallBox         "CallBox"

#define XmNpostamble       "postamble"
#define XmCPostamble       "Postamble"

#define XmNsampsize        "sampsize"
#define XmCSampsize        "Sampsize"

#define KEY 6146            /* things for shared memory */
#define MAXCALL 12          /* need to agree with twlog */
#define SHMSIZE 2 * MAXCALL /* put in another .h? */

typedef struct 
{
   char inCall[MAXCALL];    /* Note: the names are reversed */
   char outCall[MAXCALL];
}  callspt;

typedef struct 
{
   char    **buttonNames;
   int     xmitHighlight;
   float   rxFreq;
   float   txFreq;
   int     afc;
   int     net;
#if 0
   int     mainVol;
   int     outVol;
   int     inVol;
#endif
   String  call;
   int     zero;
   String  serDev;
   int     ptt;
   int     callBox;
   int     postamble;
   int     sampsize;
} AppRes;

#if 0
typedef struct 
{
   int recsrc;
   int vol;
   int pcm;
   int line;
   int mic;
   int useRec;
} MixVals;
#endif

/*
 * Function Declarations
 */
int  iniProc (char mode);
int  chk_dialout (void);
void controlsBtnCB (Widget w, XtPointer cdata, XtPointer cbs);
void popupDiagCB (Widget w, XtPointer cdata, XtPointer cbs);
void closeVideoDiagCB (Widget w, XtPointer cdata, XtPointer cbs);
void wideBtnCB (Widget w, XtPointer cdata, XtPointer cbs);
void mediunBtnCB (Widget w, XtPointer cdata, XtPointer cbs);
void narrowBtnCB (Widget w, XtPointer cdata, XtPointer cbs);
Boolean workProc(XtPointer cdata);
void appendRXtext (Widget w, char ch, int zero, XmHighlightMode mode);
void appendTXtext (char ch, int zero);
void rxScrollBarCB (Widget w, XtPointer cdata, XtPointer cbs);
void changeDisplayCB (Widget w, XtPointer cdata, XtPointer cbs);
void txTextCB (Widget w, XtPointer cdata, XtPointer cbs);
void txCB (Widget w, XtPointer cdata, XtPointer cbs);
void rxCB (Widget w, XtPointer cdata, XtPointer cbs);
void changeBG (void);
void tuneCB (Widget w, XtPointer cdata, XtPointer cbs);
void arrowCB (Widget w, XtPointer cdata, XtPointer cbs);
void freqTextCB (Widget w, XtPointer cdata, XtPointer cbs);
void afcCB (Widget w, XtPointer cdata, XtPointer cbs);
void netCB (Widget w, XtPointer cdata, XtPointer cbs);
void scopeCB (Widget w, XtPointer cdata, XtPointer cbs);
void wfCB (Widget w, XtPointer cdata, XtPointer cbs);
void wfDirCB (Widget w, XtPointer cdata, XtPointer cbs);
void localCapsCB (Widget w, XtPointer cdata, XtPointer cbs);
void openBtnCB (Widget w, XtPointer cdata, XtPointer cbs);
//void audioCB (Widget w, XtPointer cdata, XtPointer cbs);
void chansCB (Widget w, XtPointer cdata, XtPointer cbs);
void setLevel (int device, int level);
void qpskCB (Widget w, XtPointer cdata, XtPointer cbs);
void lsbCB (Widget w, XtPointer cdata, XtPointer cbs);
void dcdCB (Widget w, XtPointer cdata, XtPointer cbs);
void bwCB (Widget w, XtPointer cdata, XtPointer cbs);
void brightCB (Widget w, XtPointer cdata, XtPointer cbs);
void fftScaleCB (Widget w, XtPointer cdata, XtPointer cbs);
void fileCB (Widget w, XtPointer cdata, XtPointer cbs);
void quitCB (Widget w, XtPointer cdata, XtPointer cbs);
void aboutCB (Widget w, XtPointer cdata, XtPointer cbs);
void helpCB (Widget w, XtPointer cdata, XtPointer cbs);
void errorDiag (Widget w, char *emess, int flag, int type);
void errOkCB (Widget w, XtPointer cdata, XtPointer cbs);
void errCancelCB (Widget w, XtPointer cdata, XtPointer cbs);
void promptDiag (char *word);
Boolean procFileText (XtPointer text); 
void popupHandler (Widget w, XtPointer cdata, XEvent *event, Boolean *cont);
void clrTextCB (Widget w, XtPointer cdata, XtPointer cbs);
char *getFile (char*filename);
void rxFreqFocusCB (Widget w, XtPointer cdata, XtPointer cbs);
int open2Rx (int x);
void seekCB (Widget w, XtPointer cdata, XtPointer cbs);
void haltCB (Widget w, XtPointer cdata, XtPointer cbs);
void bordersCB (Widget w, XtPointer cdata, XtPointer cbs);
void sendOver (Widget w, XEvent *e, String args[], Cardinal *argc);
void sendHisCall (Widget w, XEvent *e, String args[], Cardinal *argc);
void sendMacro (Widget w, XEvent *e, String args[], Cardinal *argc);
char *getHisCall (void);
void procMacroText (char *ch);
void seekTimeOut (XtPointer cdata, XtIntervalId id);
void callbox (Widget shell);
void gotSig (int stat);
void infoText (char *text);
int  getQSOfiles(char *destdir);

void rxTextCB (Widget w, XtPointer cdata, XtPointer cbs);
#endif
